#!/usr/bin/perl


####################################################
# Prepared by : Lau In Siong
# Created  on : 27 Feb 2007
# updated  on : 22 Mar 2007
# added BACKUP dir
# updated  on : 23 Mar 2010
# changed to remove based on list of files/dirs
#
####################################################
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2010. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################


use strict;
use File::Basename;

my $TRUE = 0 ;
my $FALSE  = 1;
my $no_of_petty_err = 0;

my $backup_dir;

my $source_del;
my $target_dir;

& on_init;
& remove;



#############################################################
sub remove
#############################################################
{
   chop (my $curdir = `pwd`);
   my $ref_mod;
   my $backup_flag = $TRUE;

   if ((! -d "$backup_dir") || (! -e "$backup_dir"))
   {
       $backup_flag = $FALSE;
   }

   my @del_files = load2buffer ($source_del, 1);

   chdir ($target_dir)  || die ("Cant locate dir $target_dir!\n");

   if ($backup_flag == $TRUE)
   { 
      printf ("file removing of <$source_del> from <$target_dir>, backup at <$backup_dir>...\n");
   }
   else
   {
      printf ("file removing of <$source_del> from <$target_dir>...\n");
   }

   foreach my $file (@del_files)
   {
      if ( -e $file)
      {
            my $basename = basename ($file);
            my $dirname  = dirname ($file);
            if ($backup_flag == $TRUE)
            {
            `mkdir -p $backup_dir/$dirname`;
            `mv $file $backup_dir/$dirname`;
            }
            else
            {
               `rm -fr $file`;
            }
            printf ("$file removed!\n");
      }
   }
}


#############################################################
sub on_init
#############################################################
{

   & show_usage if  (! $ARGV[0] ||  ! $ARGV[1] || ! $ARGV[2] ) ;
   $source_del = $ARGV[0];
   $target_dir = $ARGV[1];
   $backup_dir = $ARGV[2];
 
   $TRUE = 0;
   $FALSE = 1;
}



##############################################################
sub load2buffer
##############################################################
{
   my ($filename, $opt) = @_;
   my @in;
   my @out = <NULL>;

   open (FILE, "$filename") || die ("load2buffer: Can't open file $filename for reading!\n");

   @in = <FILE>;
   foreach my $file (@in)
   {
      if ($opt == 1)
      {
        $file =~ s/^[ \t]+//;
        $file =~ s/[ \t]*\n$//;
      }
      #if (  ($file !~ /^#/) && (length($file)>0)  )
      #{
         push (@out, $file);
      #}
   }
   return @out;
}

##############################################################
sub chop_whitespace
##############################################################
{
   my ($strmsg) = @_;
   my $outmsg;

#   $strmsg =~ s/^[ \t]+//; # Remove any whitespace at the beginning of the line
#   $strmsg =~ s/[ \t]+\n$//;  # remove any whitespace at the end of line
#   #$strmsg =~ s/[ \t]+/ /g;

   $strmsg =~ s/^\s+//;
   $strmsg =~ s/\s+$//;
   $strmsg =~ s/\s+/ /g;


   return $strmsg;

}

#####################################################
sub show_usage
#####################################################
{
   die ("Usage: $0 del_list destdir backupdir
         del_list: where the list of files/dirs to be removed
         destdir : where starting destination to be removed.
         backupdir: Optional, where the orginial files to be backed up at.
         \n");
}


##############################################################
sub petty_err
##############################################################
{
   my $strmsg = shift;

   #printf ("PETTY ERROR: \"%s\n", $strmsg);
   &write_log ("PETTY ERROR: $strmsg\n");
   $no_of_petty_err++;
}

###########################################################
sub write_log
###########################################################
{
   my ($strmsg) = @_;

   print "$strmsg";
   print LOGFILE $strmsg;
}

############################################################
sub fatal_err
###########################################################
{
   my ($strmsg) = @_;

   &write_log ("FATAL ERROR: $strmsg\n");
   die ("Exit with died");
   #die;
}
